@@ -9,6 +9,7 @@ from unittest.case import TestCase
 import os
 import datetime
 import copy
+import requests
 from stream import serializer
 from requests.exceptions import ConnectionError, MissingSchema
 
@@ -19,8 +20,8 @@ except ImportError:
 
 def connect_debug():
     return stream.connect(
-        'gav9ygr75by3',
-        '5ws2hnua79n9qga6e2dy572qdfapwgdc83853mjm3mjp66czyb2xkahbdhs98an8',
+        'q56mdvdzreye',
+        'spmf6x2b2v2tqg93sfp5t393wfcxru58zm7jr3ynf7dmmndw5y8chux25hs63znf',
         location='us-east',
         timeout=10
     )
@@ -309,6 +310,17 @@ class ClientTest(TestCase):
         activity_id_found = activity['id'] if activity is not None else None
         self.assertEqual(activity['origin'], feed.id)
         self.assertEqual(activity_id_found, activity_id)
+
+    def test_follow_activity_copy_limit(self):
+        feed = getfeed('user', 'test_follow_acl')
+        feed1 = getfeed('user', 'test_follow_acl1')
+        actor_id = random.randint(10, 100000)
+        feed1.add_activity({ 'actor': actor_id, 'verb': 'tweet', 'object': 1 })
+        feed.follow(feed1.slug, feed1.user_id, activity_copy_limit=0)
+        time.sleep(10)
+        activities = feed.get(limit=5)['results']
+
+        self.assertEqual(len(activities), 0)
         
     def test_follow_and_delete(self):
         user_feed = getfeed('user', 'test_follow')
@@ -690,6 +702,22 @@ class ClientTest(TestCase):
             self.assertEqual(follows[0]['feed_id'], source)
             self.assertIn(follows[0]['target_id'], targets)
 
+    def test_follow_many_acl(self):
+        sources = [getfeed('user', str(i)) for i in range(10)]
+        targets = [getfeed('flat', str(i)) for i in range(10)]
+        sources_id = [source.id for source in sources]
+        targets_id = [target.id for target in targets]
+        feeds = [{'source': s, 'target': t} for s,t in zip(sources_id, targets_id)]
+
+        for target in targets:
+            target.add_activity({ 'actor': 'barry', 'object': '09', 'verb': 'tweet' })
+
+        self.c.follow_many(feeds, activity_copy_limit=0)
+
+        for source in sources:
+            activities = source.get(limit=5)['results']
+            self.assertEqual(len(activities), 0)
+
     def test_add_to_many(self):
         activity = {'actor': 1, 'verb': 'tweet', 'object': 1, 'custom': 'data'}
         feeds = [getfeed('flat', str(i)).id for i in range(10, 20)]
@@ -703,7 +731,7 @@ class ClientTest(TestCase):
         expected_parts = ['https://analytics.getstream.io/analytics/redirect/',
             'auth_type=jwt',
             'url=http%3A%2F%2Fgoogle.com%2F%3Fa%3Db%26c%3Dd',
-            'api_key=ahj2ndz7gsan',
+            'api_key=%s' % self.c.api_key,
             'events=%5B%7B%22foreign_ids%22%3A+%5B%22tweet%3A1%22%2C+%22tweet%3A2%22%2C+%22tweet%3A3%22%2C+%22tweet%3A4%22%2C+%22tweet%3A5%22%5D%2C+%22feed_id%22%3A+%22user%3Aglobal%22%2C+%22user_id%22%3A+%22tommaso%22%2C+%22location%22%3A+%22email%22%7D%2C+%7B%22user_id%22%3A+%22tommaso%22%2C+%22label%22%3A+%22click%22%2C+%22feed_id%22%3A+%22user%3Aglobal%22%2C+%22location%22%3A+%22email%22%2C+%22position%22%3A+3%2C+%22foreign_id%22%3A+%22tweet%3A1%22%7D%5D',
         ]
         engagement = {'foreign_id': 'tweet:1', 'label': 'click', 'position': 3, 'user_id': 'tommaso', 'location': 'email', 'feed_id': 'user:global'}
@@ -717,7 +745,7 @@ class ClientTest(TestCase):
         parsed_url = urlparse(redirect_url)
         qs = parse_qs(parsed_url.query)
 
-        decoded = jwt.decode(qs['authorization'][0], 'gthc2t9gh7pzq52f6cky8w4r4up9dr6rju9w3fjgmkv6cdvvav2ufe5fv7e2r9qy')
+        decoded = jwt.decode(qs['authorization'][0], self.c.api_secret)
 
         self.assertEqual(decoded, {
             'resource': 'redirect_and_track',
@@ -739,6 +767,16 @@ class ClientTest(TestCase):
         user_id = 'tommaso'
         create_redirect = lambda : self.c.create_redirect_url(target_url, user_id, events)
         self.assertRaises(MissingSchema, create_redirect)
+
+    def test_follow_redirect_url(self):
+        target_url = 'http://google.com/?a=b&c=d'
+        events = []
+        user_id = 'tommaso'
+        redirect_url = self.c.create_redirect_url(target_url, user_id, events)
+
+        res = requests.get(redirect_url)
+        res.raise_for_status()
+        self.assertTrue('google' in res.url)
         
         
         
\ No newline at end of file
